pub enum ItemType {
All,
Struct,
Enum,
Trait,
ImplType,
ImplTraitForType,
Macro,
AttributeMacro,
Function,
TypeAlias,
}Expand description
Defines various types of items that can be searched for in a crate.
This enum lists different types of code constructs like structs, enums, traits, etc.
Variants
All
Represents all item types.
Struct
A struct definition.
Enum
An enum definition.
Trait
A trait definition.
ImplType
Type implementation.
ImplTraitForType
Trait implementation for a type.
Macro
A macro definition.
AttributeMacro
An attribute macro.
Function
A standalone function.
TypeAlias
A type alias.