pub struct FileLineRange {
pub start: Option<NonZeroUsize>,
pub end: Option<NonZeroUsize>,
}Expand description
Represents a range of lines in a file.
This struct is used to specify a start and end line for operations that work with line ranges.
Fields
start: Option<NonZeroUsize>The start line number.
end: Option<NonZeroUsize>The end line number.